==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-server/src/main/java/org/apache/hadoop/hbase/errorhandling/ForeignExceptionListener.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.errorhandling;

import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.classification.InterfaceStability;

/**
 * The ForeignExceptionListener is an interface for objects that can receive a ForeignException.
 * <p>
 * Implementations must be thread-safe, because this is expected to be used to propagate exceptions
 * from foreign threads.
 */
@InterfaceAudience.Private
@InterfaceStability.Evolving
public interface ForeignExceptionListener {

  /**
   * Receive a ForeignException.
   * <p>
   * Implementers must ensure that this method is thread-safe.
   * @param e exception causing the error. Implementations must accept and handle null here.
   */
  void receive(ForeignException e);
}

==> hbase-2.5.9-src.tar.gz: hbase-2.5.9/hbase-server/src/main/java/org/apache/hadoop/hbase/errorhandling/ForeignExceptionListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.errorhandling;

import org.apache.yetus.audience.InterfaceAudience;
import org.apache.yetus.audience.InterfaceStability;

/**
 * The ForeignExceptionListener is an interface for objects that can receive a ForeignException.
 * <p>
 * Implementations must be thread-safe, because this is expected to be used to propagate exceptions
 * from foreign threads.
 */
@InterfaceAudience.Private
@InterfaceStability.Evolving
public interface ForeignExceptionListener {

  /**
   * Receive a ForeignException.
   * <p>
   * Implementers must ensure that this method is thread-safe.
   * @param e exception causing the error. Implementations must accept and handle null here.
   */
  void receive(ForeignException e);
}
